@@ -6,11 +6,11 @@ using namespace std;
 using namespace SigC;
 #endif
 
-int count=0;
+int count_=0;
 
 int foo1(int i) 
   {
-   count++;
+   count_++;
    cout<<"f("<<i<<");"<<endl;
    return 1;
   }
@@ -18,7 +18,7 @@ int foo1(int i)
 Connection c2;
 int foo2(int i) 
   {
-   count++;
+   count_++;
    cout<<"f2("<<i<<");"<<endl;
    c2.disconnect();  // this should not crash the system.
    return 1;
@@ -26,7 +26,7 @@ int foo2(int i)
 
 int main(int argc,char **argv)
   {
-   int fail=0;
+   int fail_=0;
    Signal1<int,int> sig1;  // int sig(int);
 
    Connection c;
@@ -36,12 +36,12 @@ int main(int argc,char **argv)
 
    cout << ">> Emit signal "<< endl;
    sig1.emit(1);
-   if (count!=2) fail=1;
+   if (count_!=2) fail_=1;
 
    c.disconnect();
    cout << ">> Emit signal again "<< endl;
    sig1.emit(1);
-   if (count!=2) fail=1;
+   if (count_!=2) fail_=1;
    
-   return fail;
+   return fail_;
   }
